@@ -11,6 +11,7 @@ import django.db.models
 import django.db.models.fields.files
 import django.utils.timezone
 from django.db.models import *
+from django.db.models import Model as _Model
 from django.db.transaction import atomic
 from django.utils.functional import classproperty
 from djmoney.models.fields import MoneyField
@@ -213,7 +214,7 @@ class JSONField(JSONField):
         super().__init__(*args, **kwargs)
 
 
-class DatetimeMixin(Model):
+class DatetimeMixin(_Model):
     """
     添加数据入库时间和数据更新时间两个自动字段
     """
@@ -229,7 +230,7 @@ class DatetimeMixin(Model):
     )
 
 
-class Model(DatetimeMixin, django.db.models.Model):
+class Model(DatetimeMixin, _Model):
     """
     优化的模型基类，默认包括入库时间和更新时间字段，并自动将复数名称重定义到单数名称。
 
